"""For creating an .bkpk file. CLI Arguments: <file>"""

import sys
import glob
import pickle

from . import models

def build(origin: str) -> dict:
    """Returns an dictionary with all files from a given path."""
    result = {}

    for path in glob.iglob(origin + '**', recursive=True):
        try:
            with open(path, 'rb') as f: content = f.read()
        except IsADirectoryError: content = models.Directory

        path = path.replace(origin, '')

        if path:
            result[path] = content 

    return result

def save(origin: str):
    """Wrapper for build()"""
    if not origin.endswith('/'):
        origin += '/'

    result = build(origin)
    
    target = origin[:-1].split('/')[-1] + models.FILE_EXTENSION

    with open(target, 'wb') as fp:
        pickle.dump(result, fp)

if __name__ == '__main__':
    save(sys.argv[1])



import sys
import colorama
import webbrowser

from . import pack
from . import unpack
from . import models
from . import helpers

colorama.init(autoreset=True)

def main():
    arg = sys.argv

    if len(arg) == 1:
        print(f'{colorama.Fore.BLUE}Welcome to Backpack (bkpk)!')

        if helpers.query_yes_no('Do you need help? [y=yes|n=no]\nIf so, this project\'s documentation will be opened in a browser.', default='no'):
            webbrowser.open('https://github.com/nsde/bkpk/blob/master/README.md#commands')
            print('Try pressing CTRL+C if you can\'t access the terminal properly.')
        else:
            print('If you experience issues while trying to use bkpk, please report them:\n→ https://github.com/nsde/bkpk/issues/new')

        sys.exit(0)

    if arg[-1].endswith(models.FILE_EXTENSION):
        unpack.load(arg[-1])
        print(f'{colorama.Fore.GREEN}🎒 Unpacking successful!')
    else:
        pack.save(arg[-1])
        print(f'{colorama.Fore.GREEN}🎒 Packing successful!')



import os
import sys
import pickle

from . import models

def reconstruct(name: str, package: dict) -> dict:
    """Creates all files and folders from a root folder name and package dictionary."""

    for path, content in package.items():
        path = f'{name}/{path}'

        if content is models.Directory:
            os.makedirs(path, exist_ok=True)
        else:
            os.makedirs(os.path.dirname(path), exist_ok=True)

            with open(path, 'wb') as fp:
                fp.write(content)

def load(target: str):
    """Wrapper for reconstruct()"""
    name = target.replace(models.FILE_EXTENSION, '')

    with open(target, 'rb') as fp:
        return reconstruct(name, pickle.load(fp))

if __name__ == '__main__':
    reconstruct(sys.argv[1])



import setuptools

setuptools.setup(
    install_requires=[ # According to https://github.com/pallets/flask/blob/main/setup.py#L3, this is needed for the GitHub dependency graph.
        'colorama==0.4.5',
        'setuptools==63.2.0'
    ],
)
